@@ -34,10 +34,11 @@
 #include <filesystem>
 
 #include <zeep/json/element.hpp>
-#include <mcfp.hpp>
+#include <mcfp/mcfp.hpp>
 #include <cif++/gzio.hpp>
 
 #include <pdb-redo/BondMap.hpp>
+#include <pdb-redo/Compound.hpp>
 #include <pdb-redo/Statistics.hpp>
 #include <pdb-redo/Version.hpp>
 
@@ -79,7 +80,10 @@ int density_fitness_main(int argc, char* const argv[])
 		mcfp::make_option("use-auth-ids", "Write auth_ identities instead of label_"),
 		mcfp::make_option<std::string>("mmcif-dictionary", "Path to the mmcif_pdbx.dic file to use instead of default"),
 		mcfp::make_option<std::string>("compounds", "Location of the components.cif file from CCD"),
-		mcfp::make_option<std::string>("extra-compounds", "File containing residue information for extra compounds in this specific target, should be either in CCD format or a CCP4 restraints file")
+
+		mcfp::make_option<std::string>("restraint-dict", "File containing restraints for residues in this specific target, can be specified multiple times."),
+		mcfp::make_option<std::string>("ccd-dict", "Dictionary file containing information in CCD format for residues in this specific target, can be specified multiple times.")
+
 	);
 
 	config.parse(argc, argv);
@@ -154,9 +158,14 @@ int density_fitness_main(int argc, char* const argv[])
 	if (config.has("compounds"))
 		cif::add_file_resource("components.cif", config.get<std::string>("compounds"));
 	
-	if (config.has("extra-compounds"))
-		cif::compound_factory::instance().push_dictionary(config.get<std::string>("extra-compounds"));
+	// Load dictionaries, if any
+
+	if (config.has("ccd-dict"))
+		cif::compound_factory::instance().push_dictionary(config.get<std::string>("ccd-dict"));
 	
+	if (config.has("restraint-dict"))
+		pdb_redo::CompoundFactory::instance().pushDictionary(config.get<std::string>("restraint-dict"));
+
 	// And perhaps a private mmcif_pdbx dictionary
 
 	if (config.has("mmcif-dictionary"))
